Extract Raw Predictions at Sample Locations
Source:R/model_evaluation.R
maxent_extract_predictions_raw.RdGets Java Maxent raw scores at specific grid cell locations: $$raw = \frac{exp(lp - lpNorm)}{densityNorm}$$
R/model_evaluation.R
maxent_extract_predictions_raw.RdGets Java Maxent raw scores at specific grid cell locations: $$raw = \frac{exp(lp - lpNorm)}{densityNorm}$$