Generates a response curve by varying one environmental variable from its minimum to maximum value while holding all other variables at their mean. Applies the Java Maxent cloglog transform, matching the output of Java Maxent and dismo: $$cloglog = 1 - exp(-exp(H) \cdot raw)$$
Generates a response curve by varying one environmental variable from its minimum to maximum value while holding all other variables at their mean. Applies the Java Maxent cloglog transform, matching the output of Java Maxent and dismo: $$cloglog = 1 - exp(-exp(H) \cdot raw)$$
Usage
maxent_response_curve(
model,
env_grids,
feature_names,
var_index,
n_steps = 100L
)
maxent_response_curve(
model,
env_grids,
feature_names,
var_index,
n_steps = 100L
)Value
A data.frame with columns:
- value
Environmental variable value
- prediction
Cloglog-transformed prediction
A data.frame with columns:
- value
Environmental variable value
- prediction
Cloglog-transformed prediction
Examples
if (FALSE) { # \dontrun{
curve <- maxent_response_curve(model, list(g1, g2),
c("temp", "precip"), var_index = 0)
plot(curve$value, curve$prediction, type = "l")
} # }
if (FALSE) { # \dontrun{
curve <- maxent_response_curve(model, list(g1, g2),
c("temp", "precip"), var_index = 0)
plot(curve$value, curve$prediction, type = "l")
} # }