Compute MESS (Multivariate Environmental Similarity Surface)
Source:R/RcppExports.R
compute_mess.RdMeasures how similar each cell is to the training environment. Negative values indicate novel (non-analog) conditions.
R/RcppExports.R
compute_mess.RdMeasures how similar each cell is to the training environment. Negative values indicate novel (non-analog) conditions.